@@ -38,6 +38,8 @@ ACTION_LOCK_JAMMED = "jammed"
 ACTION_HOMEKEY_LOCK = "homekey_lock"
 ACTION_HOMEKEY_UNLATCH = "homekey_unlatch"
 ACTION_HOMEKEY_UNLOCK = "homekey_unlock"
+ACTION_LINKED_LOCK = "linked_lock"
+ACTION_LINKED_UNLOCK = "linked_unlock"
 
 ACTION_DOOR_OPEN = "dooropen"
 ACTION_DOOR_OPEN_2 = "door_open"
@@ -75,6 +77,8 @@ ACTIVITY_ACTIONS_LOCK_OPERATION = {
     ACTION_HOMEKEY_LOCK,
     ACTION_HOMEKEY_UNLATCH,
     ACTION_HOMEKEY_UNLOCK,
+    ACTION_LINKED_LOCK,
+    ACTION_LINKED_UNLOCK,
     ACTION_LOCK_AUTO_LOCK,
     ACTION_LOCK_ONETOUCHLOCK,
     ACTION_LOCK_ONETOUCHLOCK_2,
@@ -107,6 +111,8 @@ ACTIVITY_TO_FIRST_LAST_NAME = {
     ACTION_HOMEKEY_LOCK: ("Homekey", "Lock"),
     ACTION_HOMEKEY_UNLATCH: ("Homekey", "Unlatch"),
     ACTION_HOMEKEY_UNLOCK: ("Homekey", "Unlock"),
+    ACTION_LINKED_LOCK: ("Linked", "Lock"),
+    ACTION_LINKED_UNLOCK: ("Linked", "Unlock"),
     ACTION_LOCK_AUTO_LOCK: ("Auto", "Lock"),
     ACTION_LOCK_ONETOUCHLOCK: ("One-Touch", "Lock"),
     ACTION_LOCK_ONETOUCHLOCK_2: ("One-Touch", "Lock"),
@@ -161,6 +167,8 @@ ACTIVITY_ACTION_STATES: dict[str, LockStatus | LockDoorStatus] = {
     ACTION_RF_UNLATCH: LockStatus.UNLATCHED,
     ACTION_RF_UNLOCK: LockStatus.UNLOCKED,
     ACTION_HOMEKEY_LOCK: LockStatus.LOCKED,
+    ACTION_LINKED_LOCK: LockStatus.LOCKED,
+    ACTION_LINKED_UNLOCK: LockStatus.UNLOCKED,
     ACTION_HOMEKEY_UNLATCH: LockStatus.UNLATCHED,
     ACTION_HOMEKEY_UNLOCK: LockStatus.UNLOCKED,
     ACTION_LOCK_AUTO_LOCK: LockStatus.LOCKED,
