@@ -41,7 +41,7 @@ from .api_common import (
 )
 from .const import DEFAULT_BRAND
 from .doorbell import Doorbell, DoorbellDetail
-from .exceptions import AugustApiAIOHTTPError
+from .exceptions import YaleApiError, InvalidAuth
 from .lock import (
     Lock,
     LockDetail,
@@ -65,6 +65,22 @@ def _obscure_payload(payload: dict[str, Any]) -> dict[str, Any]:
     return payload
 
 
+def _obscure_headers(headers: dict[str, Any]) -> dict[str, Any]:
+    """Obscure the headers for logging."""
+    if headers is None:
+        return None
+    for obscure_header in (
+        "x-august-access-token",
+        "x-access-token",
+        "x-august-api-key",
+        "x-api-key",
+    ):
+        if obscure_header in headers:
+            headers = headers.copy()
+            headers[obscure_header] = "****"
+    return headers
+
+
 class ApiAsync(ApiCommon):
     """Async api."""
 
@@ -384,6 +400,22 @@ class ApiAsync(ApiCommon):
         )
         return access_token
 
+    async def async_add_websocket_subscription(
+        self, access_token: str
+    ) -> dict[str, Any]:
+        """Add a websocket subscription."""
+        response = await self._async_dict_to_api(
+            self._build_websocket_subscribe_request(access_token)
+        )
+        return await response.json()
+
+    async def async_get_websocket_subscriptions(self, access_token: str) -> str:
+        """Get websocket subscriptions."""
+        response = await self._async_dict_to_api(
+            self._build_websocket_get_request(access_token)
+        )
+        return await response.text()
+
     async def _async_dict_to_api(self, api_dict: dict[str, Any]) -> ClientResponse:
         url = api_dict.pop("url")
         method = api_dict.pop("method")
@@ -408,7 +440,7 @@ class ApiAsync(ApiCommon):
             _LOGGER.debug(
                 "About to call %s with header=%s and payload=%s",
                 url,
-                api_dict["headers"],
+                _obscure_headers(api_dict["headers"]),
                 _obscure_payload(payload),
             )
 
@@ -427,7 +459,7 @@ class ApiAsync(ApiCommon):
                 # We may get [Errno 104] Connection reset by peer or a
                 # transient disconnect/SSL error
                 if attempts == API_RETRY_ATTEMPTS:
-                    raise AugustApiAIOHTTPError(
+                    raise YaleApiError(
                         f"Failed to connect to August API: {ex}", ex
                     ) from ex
                 await asyncio.sleep(API_EXCEPTION_RETRY_TIME)
@@ -437,12 +469,15 @@ class ApiAsync(ApiCommon):
                     "Received API response from url: %s, code: %s, headers: %s, content: %s",
                     url,
                     response.status,
-                    response.headers,
+                    _obscure_headers(response.headers),
                     await response.read(),
                 )
-            if response.status == 429:
+            if response.status in (429, 502):
+                # 429 - rate limited
+                # 502 - bad gateway
                 _LOGGER.debug(
-                    "August sent a 429 (attempt: %d), sleeping and trying again",
+                    "API sent a %s (attempt: %d), sleeping and trying again",
+                    response.status,
                     attempts,
                 )
                 await asyncio.sleep(API_RETRY_TIME)
@@ -460,24 +495,24 @@ def _raise_response_exceptions(response: ClientResponse) -> None:
         response.raise_for_status()
     except ClientResponseError as err:
         if err.status in (HTTPStatus.UNAUTHORIZED, HTTPStatus.FORBIDDEN):
-            raise AugustApiAIOHTTPError(
+            raise InvalidAuth(
                 f"Authentication failed: Verify brand is correct: {err.message}", err
             ) from err
         if err.status == 422:
-            raise AugustApiAIOHTTPError(
+            raise YaleApiError(
                 f"The operation failed because the bridge (connect) is offline: {err.message}",
                 err,
             ) from err
         if err.status == 423:
-            raise AugustApiAIOHTTPError(
+            raise YaleApiError(
                 f"The operation failed because the bridge (connect) is in use: {err.message}",
                 err,
             ) from err
         if err.status == 408:
-            raise AugustApiAIOHTTPError(
+            raise YaleApiError(
                 f"The operation timed out because the bridge (connect) failed to respond: {err.message}",
                 err,
             ) from err
-        raise AugustApiAIOHTTPError(
+        raise YaleApiError(
             f"The operation failed with error code {err.status}: {err.message}.", err
         ) from err
