@@ -20,12 +20,15 @@ from ..doorbell import ContentTokenExpired, Doorbell, DoorbellDetail
 from ..exceptions import AugustApiAIOHTTPError
 from ..lock import Lock, LockDetail
 from ..pubnub_activity import activities_from_pubnub_message
-from ..pubnub_async import AugustPubNub, async_create_pubnub
+from ..pubnub_async import AugustPubNub
 from .activity import ActivityStream
 from .const import MIN_TIME_BETWEEN_DETAIL_UPDATES
 from .exceptions import CannotConnect, YaleXSError
 from .gateway import Gateway
 from .subscriber import SubscriberMixin
+from .ratelimit import _RateLimitChecker
+from ..backports.functools import cached_property
+from .socketio import SocketIORunner
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -74,11 +77,12 @@ class YaleXSData(SubscriberMixin):
         self._doorbells_by_id: dict[str, Doorbell] = {}
         self._locks_by_id: dict[str, Lock] = {}
         self._house_ids: set[str] = set()
-        self._pubnub_unsub: Callable[[], Coroutine[Any, Any, None]] | None = None
+        self._push_unsub: Callable[[], Coroutine[Any, Any, None]] | None = None
         self._initial_sync_task: asyncio.Task | None = None
         self._error_exception_class = error_exception_class
+        self._shutdown: bool = False
 
-    @property
+    @cached_property
     def brand(self) -> Brand:
         """Return the brand of the API."""
         return self._gateway.api.brand
@@ -86,6 +90,9 @@ class YaleXSData(SubscriberMixin):
     async def async_setup(self) -> None:
         """Async setup of august device data and activities."""
         token = await self._gateway.async_get_access_token()
+        await _RateLimitChecker.check_rate_limit(token)
+        await _RateLimitChecker.register_wakeup(token)
+
         # This used to be a gather but it was less reliable with august's recent api changes.
         locks: list[Lock] = await self._api.async_get_operable_locks(token) or []
         doorbells: list[Doorbell] = await self._api.async_get_doorbells(token) or []
@@ -105,7 +112,7 @@ class YaleXSData(SubscriberMixin):
         self._remove_inoperative_doorbells()
         await self.async_setup_activity_stream()
 
-        if self._locks_by_id:
+        if self._locks_by_id and self.brand is not Brand.YALE_GLOBAL:
             # Do not prevent setup as the sync can timeout
             # but it is not a fatal error as the lock
             # will recover automatically when it comes back online.
@@ -117,17 +124,19 @@ class YaleXSData(SubscriberMixin):
         """Set up the activity stream."""
         token = await self._gateway.async_get_access_token()
         user_data = await self._api.async_get_user(token)
-        pubnub = AugustPubNub()
-        for device in self._device_detail_by_id.values():
-            pubnub.register_device(device)
+        push: AugustPubNub | SocketIORunner
+        if self.brand is Brand.YALE_GLOBAL:
+            push = SocketIORunner(self._gateway)
+        else:
+            push = AugustPubNub()
+            for device in self._device_detail_by_id.values():
+                push.register_device(device)
         self.activity_stream = ActivityStream(
-            self._api, self._gateway, self._house_ids, pubnub
+            self._api, self._gateway, self._house_ids, push
         )
         await self.activity_stream.async_setup()
-        pubnub.subscribe(self.async_pubnub_message)
-        self._pubnub_unsub = async_create_pubnub(
-            user_data["UserID"], pubnub, self.brand
-        )
+        push.subscribe(self.async_push_message)
+        self._push_unsub = await push.run(user_data["UserID"], self.brand)
 
     async def _async_initial_sync(self) -> None:
         """Attempt to request an initial sync."""
@@ -137,7 +146,7 @@ class YaleXSData(SubscriberMixin):
         for result in await asyncio.gather(
             *[
                 create_eager_task(
-                    self.async_status_async(
+                    self._async_status_async(
                         device_id, bool(detail.bridge and detail.bridge.hyper_bridge)
                     )
                 )
@@ -155,10 +164,10 @@ class YaleXSData(SubscriberMixin):
                     exc_info=result,
                 )
 
-    def async_pubnub_message(
+    def async_push_message(
         self, device_id: str, date_time: datetime, message: dict[str, Any]
     ) -> None:
-        """Process a pubnub message."""
+        """Process a push message."""
         device = self.get_device_detail(device_id)
         activities = activities_from_pubnub_message(device, date_time, message)
         activity_stream = self.activity_stream
@@ -170,14 +179,15 @@ class YaleXSData(SubscriberMixin):
 
     async def async_stop(self, *args: Any) -> None:
         """Stop the subscriptions."""
-        if self._pubnub_unsub:
-            await self._pubnub_unsub()
+        self._shutdown = True
         if self.activity_stream:
             self.activity_stream.async_stop()
         if self._initial_sync_task:
             self._initial_sync_task.cancel()
             with suppress(asyncio.CancelledError):
                 await self._initial_sync_task
+        if self._push_unsub:
+            await self._push_unsub()
 
     @property
     def doorbells(self) -> ValuesView[Doorbell]:
@@ -193,7 +203,10 @@ class YaleXSData(SubscriberMixin):
         """Return the py-august LockDetail or DoorbellDetail object for a device."""
         return self._device_detail_by_id[device_id]
 
-    async def _async_refresh(self, time: datetime) -> None:
+    async def _async_refresh(self) -> None:
+        """Refresh data."""
+        if self._shutdown:
+            return
         await self._async_refresh_device_detail_by_ids(self._subscriptions.keys())
 
     async def _async_refresh_device_detail_by_ids(
@@ -238,6 +251,8 @@ class YaleXSData(SubscriberMixin):
         )
 
     async def _async_refresh_device_detail_by_id(self, device_id: str) -> None:
+        if self._shutdown:
+            return
         if device_id in self._locks_by_id:
             if self.activity_stream and self.push_updates_connected:
                 saved_attrs = _save_live_attrs(self._device_detail_by_id[device_id])
@@ -317,6 +332,14 @@ class YaleXSData(SubscriberMixin):
         )
 
     async def async_status_async(self, device_id: str, hyper_bridge: bool) -> str:
+        """Request status of the device but do not wait for a response since it will come via pubnub."""
+        token = await self._gateway.async_get_access_token()
+        await _RateLimitChecker.check_rate_limit(token)
+        result = await self._async_status_async(device_id, hyper_bridge)
+        await _RateLimitChecker.register_wakeup(token)
+        return result
+
+    async def _async_status_async(self, device_id: str, hyper_bridge: bool) -> str:
         """Request status of the device but do not wait for a response since it will come via pubnub."""
         return await self._async_call_api_op_requires_bridge(
             device_id,
@@ -403,7 +426,7 @@ class YaleXSData(SubscriberMixin):
         try:
             return await doorbell.async_get_doorbell_image(aiohttp_session, timeout)
         except ContentTokenExpired:
-            if self.brand != Brand.YALE_HOME:
+            if self.brand not in (Brand.YALE_HOME, Brand.YALE_GLOBAL):
                 raise
             _LOGGER.debug(
                 "Error fetching camera image, updating content-token from api to retry"
